
// package JavaBench;

public class ArrayJavaBench
{

  final static int maxArrayCopy = 10000;
  final static int maxArrayAccess = 500000;


  private ArrayJavaBench()
  {
  }

  /**
   * erzeuge ein int Array der Dimension dimension 
   * und gib dieses als Ergebnis zurueck
   */
  static int[] createIntArray(int dimension)
  {
    int[] baseTypeArray = new int[dimension];
    for( int i=0; i<dimension; i++ )
      {
	baseTypeArray[i] = i;
      }
    return baseTypeArray;
  }


  /**
   * kopiere ein int Array der Groesse dimension 
   * mit der System.arraycopy Methode
   * maxArrayCopy mal und gebe die benoetigte Zeit als Ergebnis zurueck
   */
  private static long SystemCopyBaseTypeArray(int dimension)
  {
    int[] baseTypeArray = createIntArray(dimension);
    int[] copyTo = new int[dimension];
    long t1 = System.currentTimeMillis();
    for( int j=0; j<maxArrayCopy; j++)
      {
	System.arraycopy( baseTypeArray, 0, copyTo, 0, dimension );
      }
    long t2 = System.currentTimeMillis();
    return ( t2 - t1 );
  }

  /**
   * kopiere ein int Array der Groesse dimension mit einer for-Schleife
   * maxArrayCopy mal und gebe die benoetigte Zeit als Ergebnis zurueck
   */
  private static long copyBaseTypeArray(int dimension)
  {
    int[] baseTypeArray = createIntArray(dimension);
    int[] copyTo = new int[dimension];
    long t1 = System.currentTimeMillis();
    for( int j=0; j<maxArrayCopy; j++)
      {
	for( int i=0; i<dimension; i++ )
	  copyTo[i] = baseTypeArray[i];
      }
    long t2 = System.currentTimeMillis();
    return ( t2 - t1 );
  }


  /**
   * main-Methode zum Testen dieser Klasse
   */
  public static void main(String[] args)
  {
    int dimension = 5000;

    System.out.println("\n    " + maxArrayCopy + " Array-Kopier-Vergleiche (Dimension: " + dimension + ")\n");
    long t1 = SystemCopyBaseTypeArray(dimension);
    System.out.println("int Array mit System.arraycopy: " + t1 + "   " + ( (double)t1 / maxArrayCopy) );
    long t3 = copyBaseTypeArray(dimension);
    System.out.println("int Array mit einer for-Schleife: " + t3 + "   " + ( (double)t3 / maxArrayCopy) );

  }



}

